@@ -14,19 +14,13 @@ import Data.GenValidity
 import Test.Hspec
 import Test.QuickCheck
 
-idempotentOnGen
-    :: (Show a, Eq a)
-    => (a -> a) -> Gen a -> (a -> [a]) -> Property
+idempotentOnGen :: (Show a, Eq a) => (a -> a) -> Gen a -> (a -> [a]) -> Property
 idempotentOnGen f gen s = forAllShrink gen s $ \a -> f (f a) `shouldBe` f a
 
-idempotentOnValid
-    :: (Show a, Eq a, GenValid a)
-    => (a -> a) -> Property
+idempotentOnValid :: (Show a, Eq a, GenValid a) => (a -> a) -> Property
 idempotentOnValid func = idempotentOnGen func genValid shrinkValid
 
-idempotent
-    :: (Show a, Eq a, GenUnchecked a)
-    => (a -> a) -> Property
+idempotent :: (Show a, Eq a, GenUnchecked a) => (a -> a) -> Property
 idempotent func = idempotentOnGen func genUnchecked shrinkUnchecked
 
 -- |
@@ -38,7 +32,5 @@ idempotent func = idempotentOnGen func genUnchecked shrinkUnchecked
 -- 'const', given any input, is idempotent for any type as well:
 --
 -- prop> \int -> idempotentOnArbitrary (const int :: Int -> Int)
-idempotentOnArbitrary
-    :: (Show a, Eq a, Arbitrary a)
-    => (a -> a) -> Property
+idempotentOnArbitrary :: (Show a, Eq a, Arbitrary a) => (a -> a) -> Property
 idempotentOnArbitrary func = idempotentOnGen func arbitrary shrink
