@@ -10,21 +10,20 @@ module Test.Validity.GenValidity.Property
 
 import Data.GenValidity
 
-import Test.Hspec
 import Test.QuickCheck
 
+import Test.Validity.Property.Utils
+
 -- | The given generator generates only valid data points
 genGeneratesValid ::
        forall a. (Show a, Validity a)
     => Gen a
-    -> (a -> [a])
     -> Property
-genGeneratesValid gen s = forAllShrink gen s (`shouldSatisfy` isValid)
+genGeneratesValid gen = forAll gen shouldBeValid
 
 -- | The given generator generates only invalid data points
 genGeneratesInvalid ::
        forall a. (Show a, Validity a)
     => Gen a
-    -> (a -> [a])
     -> Property
-genGeneratesInvalid gen s = forAllShrink gen s (`shouldSatisfy` isInvalid)
+genGeneratesInvalid gen = forAll gen shouldBeInvalid
